/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.custom.saml.resolvers;

import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.model.User;
import com.liferay.saml.opensaml.integration.resolver.AttributeResolver;

import java.util.Map;

import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Tibor Lipusz
 */
@Component(
	immediate = true,
	property = "service.ranking:Integer=" + (Integer.MIN_VALUE + 1),
	service = AttributeResolver.class
)
public class CustomAttributeResolver implements AttributeResolver {

	@Override
	public void resolve(
		User user, AttributeResolverSAMLContext attributeResolverSAMLContext,
		AttributePublisher attributePublisher) {

		if (_log.isDebugEnabled()) {
			_log.debug("Resolving");
		}

		// Implement custom resolver logic

		_defaultAttributeResolver.resolve(
			user, attributeResolverSAMLContext, attributePublisher);
	}

	@Reference(
		target = "(component.name=com.liferay.saml.opensaml.integration.internal.resolver.DefaultAttributeResolver)",
		unbind = "-"
	)
	public void setDefaultNameIdResolver(AttributeResolver attributeResolver) {
		_defaultAttributeResolver = attributeResolver;
	}

	@Activate
	protected void activate(Map<String, Object> properties) {
		if (_log.isDebugEnabled()) {
			_log.debug("Activated");

			_log.debug(
				"Default resolver: " + _defaultAttributeResolver.getClass());
		}
	}

	private static final Log _log = LogFactoryUtil.getLog(
		CustomAttributeResolver.class);

	private AttributeResolver _defaultAttributeResolver;

}